==> react-selectize-0.0.4.tgz: package/src/simple-option.js <==
(function(){
  var ref$, filter, find, map, partitionString, React, div, input, span;
  ref$ = require('prelude-ls'), filter = ref$.filter, find = ref$.find, map = ref$.map;
  partitionString = require('./prelude-extension').partitionString;
  React = require('react');
  ref$ = React.DOM, div = ref$.div, input = ref$.input, span = ref$.span;
  module.exports = React.createClass({
    displayName: 'SimpleOption',
    statics: {
      filter: function(list, search){
        var filteredList, newOption;
        filteredList = filter(function(arg$){
          var partitions;
          partitions = arg$.partitions;
          return partitions.length > 0;
        })(
        map(function(arg$){
          var label, value;
          label = arg$.label, value = arg$.value;
          return {
            label: label,
            value: value,
            partitions: partitionString(label.toLowerCase(), search.toLowerCase())
          };
        })(
        filter(function(arg$){
          var label;
          if (arg$ != null) {
            label = arg$.label;
          }
          return !!label;
        })(
        list)));
        newOption = (function(){
          switch (false) {
          case !(search.length > 0 && typeof find(function(it){
            return it.value === search;
          })(
          list) === 'undefined'):
            return [{
              label: search,
              value: search,
              newOption: true
            }];
          default:
            return [];
          }
        }());
        return newOption.concat(filteredList);
      }
    },
    render: function(){
      var ref$, onClick, onMouseOver, onMouseOut, focused, index, label, value, newOption, partitions;
      ref$ = this.props, onClick = ref$.onClick, onMouseOver = ref$.onMouseOver, onMouseOut = ref$.onMouseOut, focused = ref$.focused, index = ref$.index, label = ref$.label, value = ref$.value, newOption = ref$.newOption, partitions = ref$.partitions;
      return div({
        className: "simple-option " + (focused ? 'focused' : ''),
        onClick: onClick,
        onMouseOver: onMouseOver,
        onMouseOut: onMouseOut
      }, index === 0 && !!newOption
        ? span(null, "Add " + label + "...")
        : map(function(arg$){
          var start, end, highlight;
          start = arg$[0], end = arg$[1], highlight = arg$[2];
          return span(highlight ? {
            className: 'highlight'
          } : null, label.substring(start, end));
        })(
        partitions));
    }
  });
}).call(this);

==> react-selectize-0.0.5.tgz: package/src/simple-option.js <==
(function(){
  var ref$, filter, find, map, partitionString, React, div, input, span;
  ref$ = require('prelude-ls'), filter = ref$.filter, find = ref$.find, map = ref$.map;
  partitionString = require('./prelude-extension').partitionString;
  React = require('react');
  ref$ = React.DOM, div = ref$.div, input = ref$.input, span = ref$.span;
  module.exports = React.createClass({
    displayName: 'SimpleOption',
    statics: {
      filter: function(list, search, arg$){
        var addOptions, filteredList, newOption;
        addOptions = arg$.addOptions;
        filteredList = filter(function(arg$){
          var partitions;
          partitions = arg$.partitions;
          return partitions.length > 0;
        })(
        map(function(arg$){
          var label, value;
          label = arg$.label, value = arg$.value;
          return {
            label: label,
            value: value,
            partitions: partitionString(label.toLowerCase(), search.toLowerCase())
          };
        })(
        filter(function(arg$){
          var label;
          if (arg$ != null) {
            label = arg$.label;
          }
          return !!label;
        })(
        list)));
        if (!addOptions) {
          return filteredList;
        }
        newOption = (function(){
          switch (false) {
          case !(search.length > 0 && typeof find(function(it){
            return it.value === search;
          })(
          list) === 'undefined'):
            return [{
              label: search,
              value: search,
              newOption: true
            }];
          default:
            return [];
          }
        }());
        return newOption.concat(filteredList);
      }
    },
    render: function(){
      var ref$, onClick, onMouseOver, onMouseOut, focused, index, label, value, addOptions, newOption, partitions;
      ref$ = this.props, onClick = ref$.onClick, onMouseOver = ref$.onMouseOver, onMouseOut = ref$.onMouseOut, focused = ref$.focused, index = ref$.index, label = ref$.label, value = ref$.value, addOptions = ref$.addOptions, newOption = ref$.newOption, partitions = ref$.partitions;
      return div({
        className: "simple-option " + (focused ? 'focused' : ''),
        onClick: onClick,
        onMouseOver: onMouseOver,
        onMouseOut: onMouseOut
      }, addOptions && (index === 0 && !!newOption)
        ? span(null, "Add " + label + "...")
        : map(function(arg$){
          var start, end, highlight;
          start = arg$[0], end = arg$[1], highlight = arg$[2];
          return span(highlight ? {
            className: 'highlight'
          } : null, label.substring(start, end));
        })(
        partitions));
    }
  });
}).call(this);
